==> zio-aws-ec2_2.12-5.17.269.1-sources.jar: zio/aws/ec2/model/ExportClientVpnClientCertificateRevocationListRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ClientVpnEndpointId
import zio.ZIO
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class ExportClientVpnClientCertificateRevocationListRequest(
    clientVpnEndpointId: ClientVpnEndpointId
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest = {
    import ExportClientVpnClientCertificateRevocationListRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
      .builder()
      .clientVpnEndpointId(
        ClientVpnEndpointId.unwrap(clientVpnEndpointId): java.lang.String
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly =
    zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
      .wrap(buildAwsValue())
}
object ExportClientVpnClientCertificateRevocationListRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest =
      zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest(
        clientVpnEndpointId
      )
    def clientVpnEndpointId: ClientVpnEndpointId
    def getClientVpnEndpointId: ZIO[Any, Nothing, ClientVpnEndpointId] =
      ZIO.succeed(clientVpnEndpointId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ) extends zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly {
    override val clientVpnEndpointId: ClientVpnEndpointId =
      zio.aws.ec2.model.primitives
        .ClientVpnEndpointId(impl.clientVpnEndpointId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ): zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.12-7.21.15.2-sources.jar: zio/aws/ec2/model/ExportClientVpnClientCertificateRevocationListRequest.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.ClientVpnEndpointId
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ExportClientVpnClientCertificateRevocationListRequest(
    clientVpnEndpointId: ClientVpnEndpointId,
    dryRun: Optional[Boolean] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest = {
    import ExportClientVpnClientCertificateRevocationListRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
      .builder()
      .clientVpnEndpointId(
        ClientVpnEndpointId.unwrap(clientVpnEndpointId): java.lang.String
      )
      .optionallyWith(dryRun.map(value => value: java.lang.Boolean))(_.dryRun)
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly =
    zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
      .wrap(buildAwsValue())
}
object ExportClientVpnClientCertificateRevocationListRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest =
      zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest(
        clientVpnEndpointId,
        dryRun.map(value => value)
      )
    def clientVpnEndpointId: ClientVpnEndpointId
    def dryRun: Optional[Boolean]
    def getClientVpnEndpointId: ZIO[Any, Nothing, ClientVpnEndpointId] =
      ZIO.succeed(clientVpnEndpointId)
    def getDryRun: ZIO[Any, AwsError, Boolean] =
      AwsError.unwrapOptionField("dryRun", dryRun)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ) extends zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly {
    override val clientVpnEndpointId: ClientVpnEndpointId =
      zio.aws.ec2.model.primitives
        .ClientVpnEndpointId(impl.clientVpnEndpointId())
    override val dryRun: Optional[Boolean] = zio.aws.core.internal
      .optionalFromNullable(impl.dryRun())
      .map(value => value: Boolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.ExportClientVpnClientCertificateRevocationListRequest
  ): zio.aws.ec2.model.ExportClientVpnClientCertificateRevocationListRequest.ReadOnly =
    new Wrapper(impl)
}
